@@ -70,7 +70,7 @@ def bquantize(x, nsd=3, abstol=eps, reltol=10 * eps):
 
     """
 
-    n = x.shape[0] if hasattr(x, 'shape') else len(x)
+    n = x.shape[0] if isinstance(x, np.ndarray) else len(x)
     #q = np.zeros((2*n, nsd)) in the original source #rep?
     y = [empty() for i in range(n)]
     offset = -np.log2(0.75)
@@ -115,5 +115,5 @@ def test_bquantize():
         assert np.prod(mcsd[i].shape) + np.prod(ycsd[i].shape) == 0 or \
                mcsd[i].shape == ycsd[i].shape
 
-        if not 0 in ycsd[i].shape:
+        if 0 not in ycsd[i].shape:
             assert np.allclose(mcsd[i], ycsd[i], atol=1e-8, rtol=1e-5)
