@@ -302,50 +302,3 @@ def realizeNTF_ct(ntf, form='FB', tdac=(0, 1), ordering=None, bp=None,
     ABCDc[np.nonzero(np.abs(ABCDc) < eps**(1./2))] = 0.
     return ABCDc, tdac2
 
-def test_realizeNTF_ct():
-    """Test function for realizeNTF_ct()"""
-    ntf = (np.array([1., 1.]), np.array([0., 0.]), 1)
-    ABCDc, tdac2 = realizeNTF_ct(ntf, 'FB')
-    ABCDc_ref = np.array(((0, 0, 1, -1),
-                          (1, 0, 0, -1.5),
-                          (0, 1, 0, 0)), dtype=np.float)
-    tdac2_ref = np.array(((-1, -1),
-                        ( 0,  1)))
-    assert np.allclose(ABCDc, ABCDc_ref, atol=1e-8, rtol=1e-5)
-    assert np.allclose(tdac2, tdac2_ref, atol=1e-8, rtol=1e-5)
-
-    ntf = (np.array([1., 1.]), np.array([0., 0.]), 1)
-    ABCDc, tdac2 = realizeNTF_ct(ntf, 'FB', tdac=[0, 1])
-    ABCDc_ref = np.array(((0, 0, 1, -1),
-                          (1, 0, 0, -1.5),
-                          (0, 1, 0, 0)), dtype=np.float)
-    tdac2_ref = np.array(((-1, -1),
-                        ( 0,  1)))
-    assert np.allclose(ABCDc, ABCDc_ref, atol=1e-8, rtol=1e-5)
-    assert np.allclose(tdac2, tdac2_ref, atol=1e-8, rtol=1e-5)
-
-    ntf = (np.array([1., 1., 1]), np.array([0., 0., 0]), 1)
-    tdac = [[1, 2], [1, 2], [[0.5, 1], [1, 1.5]], []]
-    ABCDc, tdac2 = realizeNTF_ct(ntf, 'FB', tdac)
-    ABCDc_ref = np.array((
-              (     0,      0,      0, 1.0000,-1.0000,      0,      0,      0),
-              (1.0000,      0,      0,      0,      0,-3.0000,      0,      0),
-              (     0, 1.0000,      0,      0,      0,      0,-6.0000,-2.6667),
-              (     0,      0, 1.0000,      0,      0,      0,      0,      0)))
-    tdac2_ref = np.array(((-1.0000,  -1.0000),
-                          ( 1.0000,   2.0000),
-                          ( 1.0000,   2.0000),
-                          ( 0.5000,   1.0000),
-                          ( 1.0000,   1.5000)))
-    assert np.allclose(ABCDc, ABCDc_ref, atol=1e-8, rtol=1e-4)
-    assert np.allclose(tdac2, tdac2_ref, atol=1e-8, rtol=1e-4)
-
-    # test for FF
-    ntf = (np.array([1., 1.]), np.array([0., 0.]), 1)
-    ABCDc, tdac2 = realizeNTF_ct(ntf, 'FF')
-    ABCDc_ref = np.array([[0., 0., 1., -1.],
-                          [1., 0., 0.,  0.],
-                          [ 1.5, 1., 0., 0.]])
-    tdac2_ref = np.array([[-1., -1.], [ 0., 1.]])
-    assert np.allclose(ABCDc, ABCDc_ref, atol=1e-8, rtol=1e-4)
-    assert np.allclose(tdac2, tdac2_ref, atol=1e-8, rtol=1e-4)
